#!/usr/bin/python

program_name = "mt"
program_version = "0.1"


print "Loading GTK..."

from gtk import *

print "Loading GTK...  done."

def runqueue():
  while events_pending():
    mainiteration()


#
# Config file handling, and defaults...
#

######################################################################
# Config class:
#
def is_config(obj):
  return hasattr(obj,'is_config') and obj.is_config

class config:
  is_config = 1

  def __init__(self):
    import os
    self.options = {}
    self.usrfilename = "%s/.%s.conf" % (os.environ["HOME"], program_name)
    self.globalfilename = "/etc/%s/%s.conf" % (program_name, program_name)
    self.namespace = {
      "options" : self.options,
      }

  ##################################################
  #
  def load(self):
    import os.path
    for name in [self.globalfilename, self.usrfilename]:
      if os.path.exists(name):
        self.parse(name)

  ##################################################
  #
  def parse(self, filename):
    #print "parsing %s..." % filename
    
    try:
      execfile(filename, self.namespace)
    except:
      print "Error in config file %s" % filename
      import traceback, sys
      foo = traceback.format_exception(sys.exc_type,
                                       sys.exc_value,
                                       sys.exc_traceback)
      for item in foo:
        item = item[:-1]
        print item
      print "Press Enter to continue..."
      raw_input()


######################################################################
#
class clockwin:

  def __init__(self, cfg):
    self.cfg = cfg
    self.done = 0
    self.ac_on = 0
    self.batt_px = 0.0
    self.mt = None

    self.win = GtkWindow(self.cfg.options["window type"])
    #self.win = GtkWindow()
    self.win.connect("destroy", self.destroy)
    #self.win.set_position(POS_RIGHT|POS_TOP)
    self.win.set_uposition(self.cfg.options["x"],
                           self.cfg.options["y"])
    #self.win.set_transient_for(None)
    #self.win.set_wmclass("batt", WINDOW_TOPLEVEL)
    

    self.hbox = GtkHBox()
    self.win.add(self.hbox)

    self.label = GtkLabel()
    self.label.set_text("??.???")
    self.label.set_usize(self.cfg.options["label wid"],
                         self.cfg.options["label hgt"])
    self.hbox.add(self.label)

  ##################################################
  #
  def run(self):
    import time

    self.win.show_all()

    sleeptime = self.cfg.options["sleep time"]

    if self.cfg.options["style"] == "swatch":
      self.multiplier = 1000
      self._text = self._swatch_time
    elif self.cfg.options["style"] == "millidays":
      self.multiplier = 1000.0
      self._text = self._milliday_time
    elif self.cfg.options["style"] == "centidays":
      self.multiplier = 100.0
      self._text = self._centiday_time

    while not self.done:
      self.get_info()
      self.update()
      runqueue()
      time.sleep(sleeptime)

  ##################################################
  #
  # D'oh.  Python's "%02.3f" doesn't zero-pad the front of a float.
  def _swatch_time(self, mt):
    return "@%03i" % (mt)

  def _milliday_time(self, mt):
    frac = "%.2f" % (mt % 1.0)
    return "%s%s" % ("%03i" % (mt), frac[1:])

  def _centiday_time(self, mt):
    frac = "%.3f" % (mt % 1.0)
    return "%s%s" % ("%02i" % (mt), frac[1:])

  ##################################################
  #
  def get_info(self):
    import time

    if self.cfg.options["style"] == "swatch":
      offset = 1 - time.daylight
      t = time.localtime(time.mktime(time.gmtime()) - (60*60*offset))
      #t = time.gmtime(time.mktime(time.gmtime()))
      #t = time.gmtime()
    elif self.cfg.options["local time"]:
      t = time.localtime()
    else:
      t = time.gmtime()
    self.year = t[0]
    self.month = t[1]
    self.day = t[2]
    t2 = time.time() % 1.0
    secs = t2 + t[5] + (60 * t[4]) + (60 * 60 * t[3])

    self.mt = self.multiplier * secs / (60 * 60 * 24)

    #print self.mt
    #print "%.3f" % (self.mt * 1000.0)


  ##################################################
  #
  def update(self):
    self.timestring = ""
    if self.cfg.options["date"]:
      self.timestring = "%s%s-%02i-%02i   " % \
                        (self.timestring, self.year, self.month, self.day)
    if self.cfg.options["time"]:
      #self.timestring = "%s%s" % (self.timestring, self.timeformat % (self.mt))
      self.timestring = "%s%s" % (self.timestring, self._text(self.mt))

    #print self.timestring

    self.label.set_text(self.timestring)

  ##################################################
  #
  def destroy(self, *args):
    #mainquit()
    self.done = 1

######################################################################
#
def run(args):
  #print "run(%s)" % (args)
  cfg = config()
  cfg.load()
  
  cw = clockwin(cfg)
  cw.run()


######################################################################
#
if __name__ == "__main__":
  import sys
  run(sys.argv[1:])
#else:
#  print "__name__ == %s" % __name__
